@@ -65,7 +65,9 @@ def create(project_name: str = typer.Argument("magic-server"), replace: bool = F
 @app.command()
 def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
     prefix = getattr(sys, "prefix", "")
-    print("prefix", prefix)
+    base_prefix = getattr(sys, "base_prefix", "")
+
+    print("prefix", prefix, "\nbase_prefix", base_prefix)
 
     main_filename = "main.py"
     if not Path(main_filename).exists():
